
``selkie.seq`` — Sequences and iterables
========================================

.. automodule:: selkie.seq

Coercion
--------

.. autofunction:: as_list
.. autofunction:: single
.. autofunction:: repeatable

Sequence operations
-------------------

.. autofunction:: concat
.. autofunction:: unique
.. autofunction:: cross_product
.. autofunction:: uniq
.. autoclass:: EditDistance

Sorted lists
------------
.. autofunction:: intersect
.. autofunction:: union
.. autofunction:: difference

Queue
-----		  

.. autoclass:: Queue

Data processing
---------------

.. autofunction:: nth
.. autofunction:: head
.. autofunction:: tail
.. autofunction:: product
.. autofunction:: count
.. autofunction:: counts

Mixins
------

.. autoclass:: ListProxy
.. autoclass:: MapProxy
.. autoclass:: LazyList
